Network Programming
:::::::::::::::::::::

.. toctree::
    :maxdepth: 3

    networkedprograms.rst
    http.rst
    simplestwebbrowser.rst
    retrievingimageoverhttp.rst
    retrievingwebpageswithurllib.rst
    retrievingbinaryfilesoverurllib.rst
    html.rst
    html_mixedupcode_orig.rst
    html2.rst
    parsinghtmlandscrapingtheweb.rst
    parsinghtmlusingregex.rst
    parsinghtmlusingbeautifulsoup.rst
    beautifulSoup.rst
    bonusforunixlinux.rst
    glossary.rst
    Exercises.rst
    mixedupcode.rst
    writecode.rst
